@@ -1,6 +1,7 @@
 class UserTraits(object):
 
-    def __init__(self, name=None, email=None, created_at=None):
+    def __init__(self, name=None, email=None, phone=None, created_at=None):
         self.name = name
         self.email = email
         self.created_at = created_at
+        self.phone = phone
